@@ -2,10 +2,13 @@
 
 from .embedded_credentials import get_embedded_credentials, get_project_id
 from .manager import TelemetryManager, telemetry_manager
+from .apex_telemetry import run_apex_with_telemetry, ApexTelemetryWrapper
 
 __all__ = [
     "TelemetryManager",
     "telemetry_manager",
     "get_embedded_credentials",
     "get_project_id",
+    "run_apex_with_telemetry",
+    "ApexTelemetryWrapper",
 ]
